@@ -1,4 +1,4 @@
-def cond (figure,errorratetotal,x,y,conditionx,conditiony,limitx,limity): 
+def cond (figure,errorratetotal,negerrorratedata,poserrorratedata,x,y,conditionx,conditiony,limitx,limity): 
     
     import os,glob, pandas as pd
     import numpy as np  
