@@ -1,4 +1,4 @@
-def equa (a,b,equation,limita,limitb):
+def equa (figure,errorratetotal,poserrorratedata,negerrorratedata,a,b,equation,limita,limitb):
 
     import os,glob, pandas as pd
     import numpy as np  
