@@ -1,12 +1,15 @@
-import os,glob
-#import numpy as np  
-import pandas as pd  
-import matplotlib.pyplot as plt
-import seaborn as sns
+def thres (figure,csv_stats,csv_maxmin,x):
+    
+    import os,glob, pandas as pd
+    import numpy as np  
+    import pandas as pd  
+    import matplotlib.pyplot as plt
+    import seaborn as sns
+    import numexpr as ne
 
-def thres (path,figure,csv_stats,csv_maxmin,x):
     #convert all varible to positive.
-    df = pd.read_csv(path)
+    url = 'https://raw.githubusercontent.com/msyazwanfaid/hilalpy/main/Final.csv'
+    df = pd.read_csv(url, index_col=0)
     df[x] = abs(df[x])
     #df=df[(df[x] <= 20)]
 
@@ -26,6 +29,7 @@ def thres (path,figure,csv_stats,csv_maxmin,x):
     dft = df[["M",x]] 
     df_by_m = dft.groupby('M')
     df_by_m.describe().to_csv(csv_stats)
+    print(df_by_m.describe())
 
     #find Naked Eye Minimum
     dfne = df[df['M'] =='NE']
